RapideTicketDioInterceptor class

Captures a compact rolling history of Dio calls made by the host app.

Add it to any app Dio client:

dio.interceptors.add(RapideTicketDioInterceptor());

The recent calls are appended to Rapide Ticket issue metadata automatically.

Constructors

RapideTicketDioInterceptor({int maxBodyPreviewLength = 160})

Properties

hashCode int
The hash code for this object.
no setterinherited
maxBodyPreviewLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioException err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited